@@ -13,10 +13,10 @@ def softmax_row_kernel(D: torch.Tensor) -> torch.Tensor:
     """Kernel function that applies softmax on the rows.
 
     Args:
-        D (torch.Tensor): Distance matrix.
+        D: Distance matrix.
 
     Returns:
-        torch.Tensor: Weight matrix.
+        Weight matrix.
     """
     return torch.softmax(-D, 1)
 
@@ -25,10 +25,10 @@ def softmax_column_kernel(D: torch.Tensor) -> torch.Tensor:
     """Kernel function that applies softmax on the columns.
 
     Args:
-        D (torch.Tensor): Distance matrix.
+        D: Distance matrix.
 
     Returns:
-        torch.Tensor: Weight matrix.
+        Weight matrix.
     """
     return torch.softmax(-D, 0)
 
@@ -52,18 +52,18 @@ def make_loss(
     """Create a loss function for Slisemap to optimise
 
     Args:
-        local_model (Callable[[torch.Tensor, torch.Tensor], torch.Tensor]): Prediction function for the local models.
-        local_loss (Callable[[torch.Tensor, torch.Tensor, torch.Tensor], torch.Tensor]): Loss function for the local models.
-        distance (Callable[[torch.Tensor, torch.Tensor], torch.Tensor]): Embedding distance function. Defaults to `torch.cdist` (Euclidean distance).
-        kernel (Callable[[torch.Tensor], torch.Tensor]): Kernel for embedding distances, Defaults to `softmax_kernel`.
-        radius (float, optional): For enforcing the radius of Z. Defaults to 3.5.
-        lasso (float, optional): Lasso-regularisation coefficient for B ($\\lambda_{lasso} * ||B||_1$). Defaults to 0.0.
-        ridge (float, optional): Ridge-regularisation coefficient for B ($\\lambda_{ridge} * ||B||_2$). Defaults to 0.0.
-        z_norm (float, optional): Z normalisation regularisation coefficient ($\\lambda_{norm} * (sum(Z^2)-n)^2$). Defaults to 1.0.
-        individual (bool, optional): Return individual (row-wise) losses. Defaults to False.
+        local_model: Prediction function for the local models.
+        local_loss: Loss function for the local models.
+        distance: Embedding distance function. Defaults to `torch.cdist` (Euclidean distance).
+        kernel: Kernel for embedding distances, Defaults to `softmax_kernel`.
+        radius: For enforcing the radius of Z. Defaults to 3.5.
+        lasso: Lasso-regularisation coefficient for B ($\\lambda_{lasso} * ||B||_1$). Defaults to 0.0.
+        ridge: Ridge-regularisation coefficient for B ($\\lambda_{ridge} * ||B||_2$). Defaults to 0.0.
+        z_norm: Z normalisation regularisation coefficient ($\\lambda_{norm} * (sum(Z^2)-n)^2$). Defaults to 1.0.
+        individual: Return individual (row-wise) losses. Defaults to False.
 
     Returns:
-        (Callable[[torch.Tensor, torch.Tensor, torch.Tensor, torch.Tensor], torch.Tensor]): Loss function for SLISEMAP
+        Loss function for SLISEMAP
     """
     dim = 1 if individual else ()
     if individual and z_norm > 0:
@@ -81,13 +81,13 @@ def make_loss(
         """Slisemap loss function.
 
         Args:
-            X (torch.Tensor): Data matrix [n, m].
-            Y (torch.Tensor): Target matrix [n, k].
-            B (torch.Tensor): Local models [n, p].
-            Z (torch.Tensor): Embedding matrix [n, d].
+            X: Data matrix [n, m].
+            Y: Target matrix [n, k].
+            B: Local models [n, p].
+            Z: Embedding matrix [n, d].
 
         Returns:
-            (torch.Tensor): loss value.
+            The loss value.
         """
         if radius > 0:
             Zss = torch.sum(Z**2)
@@ -128,24 +128,24 @@ def make_marginal_loss(
     """Create a loss for adding new points with Slisemap.
 
     Args:
-        X (torch.Tensor): The existing data matrix [n_old, m].
-        Y (torch.Tensor): The existing target matrix [n_old, k].
-        B (torch.Tensor): The fitted models [n_old, p].
-        Z (torch.Tensor): The fitted embedding [n_old, d].
-        Xnew (torch.Tensor): The new data matrix [n_new, m].
-        Ynew (torch.Tensor): The new target matrix [n_new, k].
-        local_model (Callable[[torch.Tensor, torch.Tensor], torch.Tensor]): Prediction function for the local models.
-        local_loss (Callable[[torch.Tensor, torch.Tensor, torch.Tensor], torch.Tensor]): Loss function for the local models.
-        distance (Callable[[torch.Tensor, torch.Tensor], torch.Tensor]): Embedding distance function. Defaults to `torch.cdist` (Euclidean distance).
-        kernel (Callable[[torch.Tensor], torch.Tensor]): Kernel for embedding distances, Defaults to `softmax_kernel`.
-        radius (float, optional): For enforcing the radius of Z. Defaults to 3.5.
-        lasso (float, optional): Lasso-regularisation coefficient for B ($\\lambda_{lasso} * ||B||_1$). Defaults to 0.0.
-        ridge (float, optional): Ridge-regularisation coefficient for B ($\\lambda_{ridge} * ||B||_2$). Defaults to 0.0.
-        jit (bool, optional): Just-In-Time compile the loss function. Defaults to True.
+        X: The existing data matrix [n_old, m].
+        Y: The existing target matrix [n_old, k].
+        B: The fitted models [n_old, p].
+        Z: The fitted embedding [n_old, d].
+        Xnew: The new data matrix [n_new, m].
+        Ynew: The new target matrix [n_new, k].
+        local_model: Prediction function for the local models.
+        local_loss: Loss function for the local models.
+        distance: Embedding distance function. Defaults to `torch.cdist` (Euclidean distance).
+        kernel: Kernel for embedding distances, Defaults to `softmax_kernel`.
+        radius: For enforcing the radius of Z. Defaults to 3.5.
+        lasso: Lasso-regularisation coefficient for B ($\\lambda_{lasso} * ||B||_1$). Defaults to 0.0.
+        ridge: Ridge-regularisation coefficient for B ($\\lambda_{ridge} * ||B||_2$). Defaults to 0.0.
+        jit: Just-In-Time compile the loss function. Defaults to True.
 
     Returns:
-        loss (Callable[[torch.Tensor, torch.Tensor], torch.Tensor]): A marginal loss function that takes Bnew [n_new, p] and Znew [n_new, d].
-        set_new (Callable[[torch.Tensor, torch.Tensor], None]): A function for changing the Xnew [n_new, m] and Ynew [n_new, k].
+        loss: A marginal loss function that takes Bnew [n_new, p] and Znew [n_new, d].
+        set_new: A function for changing the Xnew [n_new, m] and Ynew [n_new, k].
     """
     Xcomb = torch.cat((X, Xnew), 0)
     Ycomb = torch.cat((Y, Ynew), 0)
@@ -157,8 +157,8 @@ def make_marginal_loss(
         """Set the Xnew and Ynew for the generated marginal Slisemap loss function.
 
         Args:
-            Xnew (torch.Tensor): New data matrix [n_new, m].
-            Ynew (torch.Tensor): New target matrix [n_new, k].
+            Xnew: New data matrix [n_new, m].
+            Ynew: New target matrix [n_new, k].
         """
         nonlocal Xcomb, Ycomb, L0
         Xcomb[Nold:] = Xnew
@@ -172,11 +172,11 @@ def make_marginal_loss(
         """Marginal Slisemap loss.
 
         Args:
-            B (torch.Tensor): New local models [n_new, p].
-            Z (torch.Tensor): New embedding matrix [n_new, d].
+            B: New local models [n_new, p].
+            Z: New embedding matrix [n_new, d].
 
         Returns:
-            (torch.Tensor): marginal loss value.
+            The marginal loss value.
         """
         L1 = local_loss(local_model(Xcomb, Bnew), Ycomb, Bnew)  # Nnew x Ncomb
         L = torch.cat((L0, L1), 0)  # Ncomb x Ncomb
